@@ -534,6 +534,7 @@ struct qc_mtype {
 	int	type;
 	char   *zname;		// IBM Z
 	char   *lname;		// LinuxONE
+	char   *ltype;
 	char   *zrack_type;	// IBM Z rack mount model type
 	char   *zrack_name;
 	char   *lrack_type;	// LinuxONE rack mount model type
@@ -542,34 +543,35 @@ struct qc_mtype {
 
 static struct qc_mtype mtypes[] = {
 	//     IBM Z				LinuxONE
-	{4381, "IBM 4381",			NULL,				NULL, NULL, NULL, NULL},
-	{3090, "IBM 3090",			NULL,				NULL, NULL, NULL, NULL},
-	{9221, "IBM S/390 9221",		NULL,				NULL, NULL, NULL, NULL},
-	{9021, "IBM ES/9000 9021",		NULL,				NULL, NULL, NULL, NULL},
-	{2003, "IBM S/390 Multiprise 2000",	NULL,				NULL, NULL, NULL, NULL},
-	{3000, "IBM S/390 StarterPak 3000",	NULL,				NULL, NULL, NULL, NULL},
-	{9672, "IBM S/390 9672",		NULL,				NULL, NULL, NULL, NULL},
-	{2066, "IBM zSeries 800",		NULL,				NULL, NULL, NULL, NULL},
-	{2064, "IBM zSeries 900",		NULL,				NULL, NULL, NULL, NULL},
-	{2086, "IBM zSeries 890",		NULL,				NULL, NULL, NULL, NULL},
-	{2084, "IBM zSeries 990",		NULL,				NULL, NULL, NULL, NULL},
-	{2096, "IBM System z9 BC",		NULL,				NULL, NULL, NULL, NULL},
-	{2094, "IBM System z9 EC",		NULL,				NULL, NULL, NULL, NULL},
-	{2098, "IBM System z10 BC",		NULL,				NULL, NULL, NULL, NULL},
-	{2097, "IBM System z10 EC",		NULL,				NULL, NULL, NULL, NULL},
-	{2818, "IBM zEnterprise 114",		NULL,				NULL, NULL, NULL, NULL},
-	{2817, "IBM zEnterprise 196",		NULL,				NULL, NULL, NULL, NULL},
-	{2827, "IBM zEnterprise EC12",		NULL,				NULL, NULL, NULL, NULL},
-	{2828, "IBM zEnterprise BC12",		NULL,				NULL, NULL, NULL, NULL},
-	{2965, "IBM z13s",			"IBM LinuxONE Rockhopper",	NULL, NULL, NULL, NULL},
-	{2964, "IBM z13",			"IBM LinuxONE Emperor",		NULL, NULL, NULL, NULL},
-	{3907, "IBM z14 ZR1",			"IBM LinuxONE Rockhopper II",	NULL, NULL, NULL, NULL},
-	{3906, "IBM z14",			"IBM LinuxONE Emperor II",	NULL, NULL, NULL, NULL},
-	{8561, "IBM z15",			"IBM LinuxONE III",		NULL, NULL, NULL, NULL},
-	{8562, "IBM z15 Model T02",		"IBM LinuxONE III Model LT2",	NULL, NULL, NULL, NULL},
-	{3931, "IBM z16",			"IBM LinuxONE Emperor 4",	NULL, NULL, NULL, NULL},
-	{3932, "IBM z16 A02",			"IBM LinuxONE Rockhopper 4",	"AGZ", "IBM z16 AGZ", "AGL", "IBM LinuxONE Rockhopper 4"},
-	{0,    NULL,				NULL,				NULL, NULL, NULL, NULL}
+	{4381, "IBM 4381",			NULL,				NULL, NULL, NULL, NULL, NULL},
+	{3090, "IBM 3090",			NULL,				NULL, NULL, NULL, NULL, NULL},
+	{9221, "IBM S/390 9221",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{9021, "IBM ES/9000 9021",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2003, "IBM S/390 Multiprise 2000",	NULL,				NULL, NULL, NULL, NULL, NULL},
+	{3000, "IBM S/390 StarterPak 3000",	NULL,				NULL, NULL, NULL, NULL, NULL},
+	{9672, "IBM S/390 9672",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2066, "IBM zSeries 800",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2064, "IBM zSeries 900",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2086, "IBM zSeries 890",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2084, "IBM zSeries 990",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2096, "IBM System z9 BC",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2094, "IBM System z9 EC",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2098, "IBM System z10 BC",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2097, "IBM System z10 EC",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2818, "IBM zEnterprise 114",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2817, "IBM zEnterprise 196",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2827, "IBM zEnterprise EC12",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2828, "IBM zEnterprise BC12",		NULL,				NULL, NULL, NULL, NULL, NULL},
+	{2964, "IBM z13",			"IBM LinuxONE Emperor",		NULL, NULL, NULL, NULL, NULL},
+	{2965, "IBM z13s",			"IBM LinuxONE Rockhopper",	NULL, NULL, NULL, NULL, NULL},
+	{3906, "IBM z14",			"IBM LinuxONE Emperor II",	NULL, NULL, NULL, NULL, NULL},
+	{3907, "IBM z14 ZR1",			"IBM LinuxONE Rockhopper II",	NULL, NULL, NULL, NULL, NULL},
+	{8561, "IBM z15",			"IBM LinuxONE III",		NULL, NULL, NULL, NULL, NULL},
+	{8562, "IBM z15 Model T02",		"IBM LinuxONE III Model LT2",	NULL, NULL, NULL, NULL, NULL},
+	{3931, "IBM z16",			"IBM LinuxONE Emperor 4",	NULL, NULL, NULL, NULL, NULL},
+	{3932, "IBM z16 A02",			"IBM LinuxONE Rockhopper 4",	NULL, "AGZ", "IBM z16 AGZ", "AGL", "IBM LinuxONE Rockhopper 4"},
+	{9175, "IBM z17",			"IBM LinuxONE Emperor 5",	"ML1", NULL, NULL, NULL, NULL},
+	{0,    NULL,				NULL,				NULL, NULL, NULL, NULL, NULL}
 };
 
 static int qc_post_process_ziip_thrds(struct qc_handle *hdl) {
@@ -598,12 +600,13 @@ static int qc_post_process_CEC(struct qc_handle *hdl) {
 		if (cpuid == type->type) {
 			if ((str = qc_get_attr_value_string(hdl, qc_model)) == NULL)
 				goto out;
-			if (type->lname && *str == 'L') {
+			if (type->lname && ((!type->ltype && *str == 'L')
+					     || (type->ltype && strcmp(type->ltype, str) == 0))) {
 				str = type->lname;
-    				family = QC_TYPE_FAMILY_LINUXONE;
+				family = QC_TYPE_FAMILY_LINUXONE;
 			} else if (type->lrack_type && strncmp(str, type->lrack_type, 3) == 0) {
 				str = type->lrack_name;
-    				family = QC_TYPE_FAMILY_LINUXONE;
+				family = QC_TYPE_FAMILY_LINUXONE;
 			} else if (type->zrack_type && strncmp(str, type->zrack_type, 3) == 0)
 				str = type->zrack_name;
 			else
